# Changelog

All notable changes to the MCP-Pinecone project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.3] - 2024-12-20
### Added
- Namespace support for all vector operations (search, read, upsert)
- Explicit namespace parameter in tool schemas

### Changed
- Updated MCP package to latest version

## [0.1.0 - 0.1.2]
### Added
- Initial public release
- Basic Pinecone integration with MCP
- Semantic search capabilities
- Document reading and writing
- Metadata support